/****************************************************************************
 * (C) Tokyo Cosmos Electric, Inc. (TOCOS) - 2013 all rights reserved.
 *
 * Condition to use:
 *   - The full or part of source code is limited to use for TWE (TOCOS
 *     Wireless Engine) as compiled and flash programmed.
 *   - The full or part of source code is prohibited to distribute without
 *     permission from TOCOS.
 *
 ****************************************************************************/

/****************************************************************************/
/***        Include files                                                 ***/
/****************************************************************************/
#include <string.h>

#include <jendefs.h>
#include <AppHardwareApi.h>

#include "utils.h"

#include "PingPong.h"
#include "config.h"
#include "Version.h"

// DEBUG options

#include "serial.h"
#include "fprintf.h"
#include "sprintf.h"

/****************************************************************************/
/***        ToCoNet Definitions                                           ***/
/****************************************************************************/
// Select Modules (define befor include "ToCoNet.h")
//#define ToCoNet_USE_MOD_NBSCAN // Neighbour scan module
//#define ToCoNet_USE_MOD_NBSCAN_SLAVE

// includes
#include "ToCoNet.h"
#include "ToCoNet_mod_prototype.h"

#include "app_event.h"

/****************************************************************************/
/***        Macro Definitions                                             ***/
/****************************************************************************/

/****************************************************************************/
/***        Type Definitions                                              ***/
/****************************************************************************/

typedef struct
{
    // MAC
    uint8 u8channel;
    uint16 u16addr;

    // LED Counter
    uint32 u32LedCt;

    // シーケンス番号
    uint32 u32Seq;

    // スリープカウンタ
    uint8 u8SleepCt;
} tsAppData;


/****************************************************************************/
/***        Local Function Prototypes                                     ***/
/****************************************************************************/

static void vProcessEvCore(tsEvent *pEv, teEvent eEvent, uint32 u32evarg);

static void vInitHardware(int f_warm_start);

void vSerialInit(uint32 u32Baud, tsUartOpt *pUartOpt);
static void vHandleSerialInput(void);

/****************************************************************************/
/***        Exported Variables                                            ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Variables                                               ***/
/****************************************************************************/
/* Version/build information. This is not used in the application unless we
   are in serial debug mode. However the 'used' attribute ensures it is
   present in all binary files, allowing easy identifaction... */

/* Local data used by the tag during operation */
static tsAppData sAppData;

PUBLIC tsFILE sSerStream;
tsSerialPortSetup sSerPort;

// Wakeup port
const uint32 u32DioPortWakeUp = 1UL << 7; // UART Rx Port


//***変更1
#define vPortSetHi(c)    vAHI_DioSetOutput(1UL << (c), 0)
#define vPortSetLo(c)   vAHI_DioSetOutput(0, 1UL << (c))
#define vPortSet_TrueAsLo(c, s)    vAHI_DioSetOutput((s) ? 0 : 1UL << (c), s ? 1UL << (c) : 0)
#define vPortAsInput(c)   vAHI_DioSetDirection(1UL << (c), 0)
#define vPortAsOutput(c)   vAHI_DioSetDirection(0, 1UL << (c))
#define bPortRead(c)    ((u32AHI_DioReadInput() & (1UL<<(c))) ? FALSE : TRUE) // Lo as True
#define u32PortReadBitmap() (u32AHI_DioReadInput())
#define bPortCheckBitmap(bitmap, c) ((bitmap & (1UL<<(c))) ? FALSE : TRUE)
#define vPortDisablePullup(c) vAHI_DioSetPullup(0x0, 1UL << (c))

// TWE-Lite DIP (TWELITE の標準構成)
#define PORT_OUT1 18
#define PORT_OUT2 19
#define PORT_OUT3 4
#define PORT_OUT4 9

#define PORT_INPUT1 12
#define PORT_INPUT2 13
#define PORT_INPUT3 11
#define PORT_INPUT4 16


//***変更3
void MyDelay(long Tu);
uint16 TTC=0;//TickTimerカウンタ
uint8 gTGS_F=0;//TGS2450フラグ
uint16 gTGS_N=100;//総和回数
uint16 gTGS_NC=0;//総和カウンタ
uint32 gADC;//ADC総和
void TGS2450();

/****************************************************************************
 *
 * NAME: AppColdStart
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
void cbAppColdStart(bool_t bAfterAhiInit)
{
	//****変更3
	vPortAsOutput(PORT_OUT1);//出力設定
	vPortSetLo(PORT_OUT1);//OFF設定
	vPortAsOutput(PORT_OUT2);//出力設定
	vPortSetLo(PORT_OUT2);//OFF設定

	//static uint8 u8WkState;
	if (!bAfterAhiInit) {
		// before AHI init, very first of code.

		// Register modules
		ToCoNet_REG_MOD_ALL();

	} else {
		// disable brown out detect
		vAHI_BrownOutConfigure(0,//0:2.0V 1:2.3V
				FALSE,
				FALSE,
				FALSE,
				FALSE);

		// clear application context
		memset (&sAppData, 0x00, sizeof(sAppData));
		sAppData.u8channel = CHANNEL;

		// ToCoNet configuration
		sToCoNet_AppContext.u32AppId = APP_ID;
		sToCoNet_AppContext.u8Channel = CHANNEL;

		sToCoNet_AppContext.bRxOnIdle = TRUE;

		// others
		SPRINTF_vInit128();

		// Register
		ToCoNet_Event_Register_State_Machine(vProcessEvCore);

		// Others
		vInitHardware(FALSE);

		// MAC start
		ToCoNet_vMacStart();
	}
}

/****************************************************************************
 *
 * NAME: AppWarmStart
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
static bool_t bWakeupByButton;

void cbAppWarmStart(bool_t bAfterAhiInit)
{
	if (!bAfterAhiInit) {
		// before AHI init, very first of code.
		//  to check interrupt source, etc.
		bWakeupByButton = FALSE;

		if(u8AHI_WakeTimerFiredStatus()) {
			// wake up timer
		} else
		if(u32AHI_DioWakeStatus() & u32DioPortWakeUp) {
			// woke up from DIO events
			bWakeupByButton = TRUE;
		} else {
			bWakeupByButton = FALSE;
		}
	} else {
		// Initialize hardware
		vInitHardware(TRUE);

		// MAC start
		ToCoNet_vMacStart();
	}
}

/****************************************************************************/
/***        Local Functions                                               ***/
/****************************************************************************/
/****************************************************************************
 *
 * NAME: vMain
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
void cbToCoNet_vMain(void)
{
	/* handle uart input */
	vHandleSerialInput();
}

/****************************************************************************
 *
 * NAME: cbToCoNet_vNwkEvent
 *
 * DESCRIPTION:
 *
 * PARAMETERS:      Name            RW  Usage
 *
 * RETURNS:
 *
 * NOTES:
 ****************************************************************************/
void cbToCoNet_vNwkEvent(teEvent eEvent, uint32 u32arg) {
	switch(eEvent) {
	default:
		break;
	}
}

/****************************************************************************
 *
 * NAME: cbvMcRxHandler
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
void cbToCoNet_vRxEvent(tsRxDataApp *pRx) {
	int i;
	static uint16 u16seqPrev = 0xFFFF;


	vfPrintf(&sSerStream, "\r\npRx->u8Cmd=%x\r\n",pRx->u8Cmd);
	//uint8 *p = pRx->auData;

	// print coming payload
	vfPrintf(&sSerStream, LB"[PKT Ad:%04x,Ln:%03d,Seq:%03d,Lq:%03d,Tms:%05d \"",
			pRx->u32SrcAddr,
			pRx->u8Len+4, // Actual payload byte: the network layer uses additional 4 bytes.
			pRx->u8Seq,
			pRx->u8Lqi,
			pRx->u32Tick & 0xFFFF);
	for (i = 0; i < pRx->u8Len; i++) {
		if (i < 32) {
			sSerStream.bPutChar(sSerStream.u8Device,
					(pRx->auData[i] >= 0x20 && pRx->auData[i] <= 0x7f) ? pRx->auData[i] : '.');
		} else {
			vfPrintf(&sSerStream, "..");
			break;
		}
	}
	vfPrintf(&sSerStream, "C\"]");

	// 打ち返す
	if (    pRx->u8Seq != u16seqPrev // シーケンス番号による重複チェック
		&& !memcmp(pRx->auData, "PING:", 5) // パケットの先頭は PING: の場合
	) {
		u16seqPrev = pRx->u8Seq;

		// transmit Ack back
		tsTxDataApp tsTx;
		memset(&tsTx, 0, sizeof(tsTxDataApp));

		tsTx.u32SrcAddr = ToCoNet_u32GetSerial(); //
		tsTx.u32DstAddr = pRx->u32SrcAddr; // 送り返す

		tsTx.bAckReq = TRUE;
		tsTx.u8Retry = 0;
		tsTx.u8CbId = pRx->u8Seq;
		tsTx.u8Seq = pRx->u8Seq;
		tsTx.u8Len = pRx->u8Len;
		tsTx.u8Cmd = TOCONET_PACKET_CMD_APP_DATA;

		if (tsTx.u8Len > 0) {
			memcpy(tsTx.auData, pRx->auData, tsTx.u8Len);
		}
		tsTx.auData[1] = 'O'; // メッセージを PONG に書き換える

		ToCoNet_bMacTxReq(&tsTx);

		// turn on Led a while
		sAppData.u32LedCt = u32TickCount_ms;

		// ＵＡＲＴに出力
		vfPrintf(&sSerStream, LB "Fire PONG Message to %08x" LB, pRx->u32SrcAddr);
	} else if (!memcmp(pRx->auData, "PONG:", 5)) {
		// ＵＡＲＴに出力
		vfPrintf(&sSerStream, LB "PONG Message from %08x" LB, pRx->u32SrcAddr);
	}
}

/****************************************************************************
 *
 * NAME: cbvMcEvTxHandler
 *
 * DESCRIPTION:
 *
 * PARAMETERS:      Name            RW  Usage
 *
 * RETURNS:
 *
 * NOTES:
 ****************************************************************************/
void cbToCoNet_vTxEvent(uint8 u8CbId, uint8 bStatus) {
	return;
}

/****************************************************************************
 *
 * NAME: cbToCoNet_vHwEvent
 *
 * DESCRIPTION:
 * Process any hardware events.
 *
 * PARAMETERS:      Name            RW  Usage
 *                  u32DeviceId
 *                  u32ItemBitmap
 *
 * RETURNS:
 * None.
 *
 * NOTES:
 * None.
 ****************************************************************************/
void cbToCoNet_vHwEvent(uint32 u32DeviceId, uint32 u32ItemBitmap)
{
    switch (u32DeviceId) {
    case E_AHI_DEVICE_TICK_TIMER:
    	//***変更3
    	if(gTGS_F == 1)
    	{
    		TTC++;
    		if(TTC > 62)
    		{
    			TTC=0;
    			gTGS_NC++;
    			TGS2450();
    			if(gTGS_NC > gTGS_N)
    			{
    				gTGS_NC=0;
    				vfPrintf(&sSerStream,"TGS2450-TEST=\t%d\r\n",gADC);//TEST表示
    				gADC=0;
    				//gTGS_F=0;//これを有効にすると1回で終了！！
    			}
    		}
    	}
		// LED BLINK
   		vPortSet_TrueAsLo(PORT_KIT_LED2, u32TickCount_ms & 0x400);

   		// LED ON when receive
   		if (u32TickCount_ms - sAppData.u32LedCt < 300) {
   			vPortSetLo(PORT_KIT_LED1);
   		} else {
  			vPortSetHi(PORT_KIT_LED1);
   		}
    	break;

    default:
    	break;
    }
}

/****************************************************************************
 *
 * NAME: cbToCoNet_u8HwInt
 *
 * DESCRIPTION:
 *   called during an interrupt
 *
 * PARAMETERS:      Name            RW  Usage
 *                  u32DeviceId
 *                  u32ItemBitmap
 *
 * RETURNS:
 *                  FALSE -  interrupt is not handled, escalated to further
 *                           event call (cbToCoNet_vHwEvent).
 *                  TRUE  -  interrupt is handled, no further call.
 *
 * NOTES:
 *   Do not put a big job here.
 ****************************************************************************/
uint8 cbToCoNet_u8HwInt(uint32 u32DeviceId, uint32 u32ItemBitmap) {
	return FALSE;
}

/****************************************************************************
 *
 * NAME: vInitHardware
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
static void vInitHardware(int f_warm_start)
{
	// Serial Initialize
#if 0
	// UART の細かい設定テスト
	tsUartOpt sUartOpt;
	memset(&sUartOpt, 0, sizeof(tsUartOpt));
	sUartOpt.bHwFlowEnabled = FALSE;
	sUartOpt.bParityEnabled = E_AHI_UART_PARITY_ENABLE;
	sUartOpt.u8ParityType = E_AHI_UART_EVEN_PARITY;
	sUartOpt.u8StopBit = E_AHI_UART_2_STOP_BITS;
	sUartOpt.u8WordLen = 7;

	vSerialInit(UART_BAUD, &sUartOpt);
#else
	vSerialInit(UART_BAUD, NULL);
#endif


	ToCoNet_vDebugInit(&sSerStream);
	ToCoNet_vDebugLevel(0);

	/// IOs
	vPortSetLo(PORT_KIT_LED1);
	vPortSetHi(PORT_KIT_LED2);
	vPortAsOutput(PORT_KIT_LED1);
	vPortAsOutput(PORT_KIT_LED2);
}

/****************************************************************************
 *
 * NAME: vInitHardware
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
void vSerialInit(uint32 u32Baud, tsUartOpt *pUartOpt) {
	/* Create the debug port transmit and receive queues */
	static uint8 au8SerialTxBuffer[96];
	static uint8 au8SerialRxBuffer[32];

	/* Initialise the serial port to be used for debug output */
	sSerPort.pu8SerialRxQueueBuffer = au8SerialRxBuffer;
	sSerPort.pu8SerialTxQueueBuffer = au8SerialTxBuffer;
	sSerPort.u32BaudRate = u32Baud;
	sSerPort.u16AHI_UART_RTS_LOW = 0xffff;
	sSerPort.u16AHI_UART_RTS_HIGH = 0xffff;
	sSerPort.u16SerialRxQueueSize = sizeof(au8SerialRxBuffer);
	sSerPort.u16SerialTxQueueSize = sizeof(au8SerialTxBuffer);
	sSerPort.u8SerialPort = UART_PORT_SLAVE;
	sSerPort.u8RX_FIFO_LEVEL = E_AHI_UART_FIFO_LEVEL_1;
	SERIAL_vInitEx(&sSerPort, pUartOpt);

	sSerStream.bPutChar = SERIAL_bTxChar;
	sSerStream.u8Device = UART_PORT_SLAVE;
}

/****************************************************************************
 *
 * NAME: vHandleSerialInput
 *
 * DESCRIPTION:
 *
 * PARAMETERS:      Name            RW  Usage
 *
 * RETURNS:
 *
 * NOTES:
 ****************************************************************************/
static void vHandleSerialInput(void)
{
    // handle UART command
	while (!SERIAL_bRxQueueEmpty(sSerPort.u8SerialPort)) {
		int16 i16Char;

		i16Char = SERIAL_i16RxChar(sSerPort.u8SerialPort);

		vfPrintf(&sSerStream, "\n\r# [%c] --> ", i16Char);
	    SERIAL_vFlush(sSerStream.u8Device);

		switch(i16Char) {

		case '>': case '.':
			/* channel up */
			sAppData.u8channel++;
			if (sAppData.u8channel > 26) sAppData.u8channel = 11;
			sToCoNet_AppContext.u8Channel = sAppData.u8channel;
			ToCoNet_vRfConfig();
			vfPrintf(&sSerStream, "set channel to %d.", sAppData.u8channel);
			break;

		case '<': case ',':
			/* channel down */
			sAppData.u8channel--;
			if (sAppData.u8channel < 11) sAppData.u8channel = 26;
			sToCoNet_AppContext.u8Channel = sAppData.u8channel;
			ToCoNet_vRfConfig();
			vfPrintf(&sSerStream, "set channel to %d.", sAppData.u8channel);
			break;

		case 'd': case 'D':
			_C {
				static uint8 u8DgbLvl;

				u8DgbLvl++;
				if(u8DgbLvl > 5) u8DgbLvl = 0;
				ToCoNet_vDebugLevel(u8DgbLvl);

				vfPrintf(&sSerStream, "set NwkCode debug level to %d.", u8DgbLvl);
			}
			break;

		case 's': case 'S':
			// スリープのテストコード
			_C {
				// print message.
				sAppData.u8SleepCt++;

				// stop interrupt source, if interrupt source is still running.
				;

				vfPrintf(&sSerStream, "now sleeping" LB);
				SERIAL_vFlush(sSerStream.u8Device); // flushing

				if (i16Char == 's') {
					vAHI_UartDisable(sSerStream.u8Device);
				}

				// set UART Rx port as interrupt source
				vAHI_DioSetDirection(u32DioPortWakeUp, 0); // set as input

				(void)u32AHI_DioInterruptStatus(); // clear interrupt register
				vAHI_DioWakeEnable(u32DioPortWakeUp, 0); // also use as DIO WAKE SOURCE
				// vAHI_DioWakeEdge(0, PORT_INPUT_MASK); // 割り込みエッジ（立下りに設定）
				vAHI_DioWakeEdge(u32DioPortWakeUp, 0); // 割り込みエッジ（立上がりに設定）
				// vAHI_DioWakeEnable(0, PORT_INPUT_MASK); // DISABLE DIO WAKE SOURCE

				// wake up using wakeup timer as well.
				// ToCoNet_vSleep(E_AHI_WAKE_TIMER_0, 0, FALSE, TRUE); // RAM OFF SLEEP USING WK0
				ToCoNet_vSleep(E_AHI_WAKE_TIMER_0, 0, FALSE, FALSE); // RAM ON SLEEP USING WK0
			}
			break;

		case 'p':
			// 出力調整のテスト
			_C {
				static uint8 u8pow = 3; // (MIN)0..3(MAX)

				u8pow = (u8pow + 1) % 4;
				vfPrintf(&sSerStream, "set power to %d.", u8pow);

				sToCoNet_AppContext.u8TxPower = u8pow;
				ToCoNet_vRfConfig();
			}
			break;

		case 't': // パケット送信してみる
			_C {
				// transmit Ack back
				tsTxDataApp tsTx;
				memset(&tsTx, 0, sizeof(tsTxDataApp));

				//sAppData.u32Seq++;

				tsTx.u32SrcAddr = ToCoNet_u32GetSerial(); // 自身のアドレス
				tsTx.u32DstAddr = 0xFFFF; // ブロードキャスト

				tsTx.bAckReq = FALSE;
				tsTx.u8Retry = 0x82; // ブロードキャストで都合３回送る
				//tsTx.u8CbId = sAppData.u32Seq & 0xFF;
				//tsTx.u8Seq = sAppData.u32Seq & 0xFF;
				//tsTx.u8Cmd = TOCONET_PACKET_CMD_APP_DATA;
				tsTx.u8Cmd = 0x04;

				// SPRINTF でメッセージを作成
				SPRINTF_vRewind();
				vfPrintf(SPRINTF_Stream, "PING: %08X", ToCoNet_u32GetSerial());
				memcpy(tsTx.auData, SPRINTF_pu8GetBuff(), SPRINTF_u16Length());
				tsTx.u8Len = SPRINTF_u16Length();

				// 送信
				ToCoNet_bMacTxReq(&tsTx);

				// LEDの制御
				//sAppData.u32LedCt = u32TickCount_ms;

				// ＵＡＲＴに出力
				//vfPrintf(&sSerStream, LB "Fire PING Broadcast Message.");
			}
			break;
		case 'h'://***変更1
			vfPrintf(&sSerStream,"HC-SR04-TEST\r\n");//TEST表示
			vPortAsInput(PORT_INPUT1);//入力設定
			//vPortAsOutput(PORT_OUT1);//出力設定
			vPortAsOutput(PORT_INPUT2);//出力設定

			//vPortSetLo(PORT_OUT1);//トリガOFF
			vPortSetLo(PORT_INPUT2);//トリガOFF
			vAHI_TimerEnable(E_AHI_TIMER_4,3,FALSE,FALSE,FALSE);//プレスケール1/8設定
			vAHI_TimerStartSingleShot(E_AHI_TIMER_4,0x0000,0x0000);//タイマー4スタート
			while(u16AHI_TimerReadCount(E_AHI_TIMER_4) < 20);//10μsディレイ

			//vPortSetHi(PORT_OUT1);//トリガON
			vPortSetHi(PORT_INPUT2);//トリガON
			vAHI_TimerStop (E_AHI_TIMER_4);//タイマー4ストップ
			vAHI_TimerStartRepeat(E_AHI_TIMER_4,0x0000,0x0000);//タイマー4スタート
			while(u16AHI_TimerReadCount(E_AHI_TIMER_4) != 20);//10μsディレイ

			//vPortSetLo(PORT_OUT1);//トリガOFF
			vPortSetLo(PORT_INPUT2);//トリガOFF
			vAHI_TimerStop (E_AHI_TIMER_4);//タイマー4ストップ
			vAHI_TimerStartRepeat(E_AHI_TIMER_4,0x0000,0x0000);//タイマー4スタート
			while(bPortRead(PORT_INPUT1) &&  u16AHI_TimerReadCount(E_AHI_TIMER_4) != 0xffff);//エコーON

			vAHI_TimerStop (E_AHI_TIMER_4);//タイマー4ストップ
			vAHI_TimerStartRepeat(E_AHI_TIMER_4,0x0000,0x0000);//タイマー4スタート
			while(!bPortRead(PORT_INPUT1) &&  u16AHI_TimerReadCount(E_AHI_TIMER_4) != 0xffff);//エコーOFF
			vfPrintf(&sSerStream,"TimerReadCount=%d\r\n",u16AHI_TimerReadCount(E_AHI_TIMER_4));//結果出力
			vAHI_TimerStop (E_AHI_TIMER_4);//タイマー4ストップ
			break;

		case 'i'://***変更2
			vfPrintf(&sSerStream,"ADC-TEST\r\n");//TEST表示
			if (!bAHI_APRegulatorEnabled())//REGULATORがOFFの場合
			{
				//REGULATOR許可、割込み無し、サンプリング間隔2、500KHz、内部クロックを設定
				vAHI_ApConfigure(E_AHI_AP_REGULATOR_ENABLE, E_AHI_AP_INT_DISABLE,E_AHI_AP_SAMPLE_2,E_AHI_AP_CLOCKDIV_500KHZ,E_AHI_AP_INTREF);
				while(!bAHI_APRegulatorEnabled());//REGULATORがON待ち
			}
			//シングルショット、レンジ0からVref、AI1を設定
			//AI1=E_AHI_ADC_SRC_ADC_1,AI2=E_AHI_ADC_SRC_ADC_3,AI3=E_AHI_ADC_SRC_ADC_2,AI4=E_AHI_ADC_SRC_ADC_4
			vAHI_AdcEnable(E_AHI_ADC_SINGLE_SHOT,E_AHI_AP_INPUT_RANGE_1,E_AHI_ADC_SRC_ADC_1);
			vAHI_AdcStartSample();//測定開始
			while(bAHI_AdcPoll());//AD変換待ち
			uint16 ADC=u16AHI_AdcRead();//結果読み込み
			vfPrintf(&sSerStream,"ADC=%d\r\n",ADC);//結果出力
			long T=(ADC*872)/688-600;//x0.1℃
			vfPrintf(&sSerStream,"Temperature(x0.1Degree)=%d\r\n",T);//温度出力
			break;

		case 'j'://***変更3
			vfPrintf(&sSerStream,"TGS2450-TEST\r\n");//TEST表示

			gTGS_F=1;//フラグON

			if (!bAHI_APRegulatorEnabled())//REGULATORがOFFの場合
			{
				//REGULATOR許可、割込み無し、サンプリング間隔2、500KHz、内部クロックを設定
				vAHI_ApConfigure(E_AHI_AP_REGULATOR_ENABLE, E_AHI_AP_INT_DISABLE,E_AHI_AP_SAMPLE_2,E_AHI_AP_CLOCKDIV_500KHZ,E_AHI_AP_INTREF);
				while(!bAHI_APRegulatorEnabled());//REGULATORがON待ち
			}

			break;
		default:
			break;
		}

		vfPrintf(&sSerStream, LB);
	    SERIAL_vFlush(sSerStream.u8Device);
	}
}

//***変更3
void MyDelay(long Tu)
{
	vAHI_TimerEnable(E_AHI_TIMER_4,4,FALSE,FALSE,FALSE);//プレスケール1/16設定
	vAHI_TimerStartSingleShot(E_AHI_TIMER_4,0x0000,0x0000);//タイマー4スタート
	while(u16AHI_TimerReadCount(E_AHI_TIMER_4) < Tu);//Tuμsディレイ
	vAHI_TimerStop (E_AHI_TIMER_4);//タイマー4ストップ
	vAHI_TimerDisable (E_AHI_TIMER_4);//タイマー開放

}

void TGS2450()
{
	vPortSetHi(PORT_OUT1);//ON設定
	MyDelay(3000);
	vPortSetHi(PORT_OUT2);//ON設定
	MyDelay(5000);
	vAHI_AdcEnable(E_AHI_ADC_SINGLE_SHOT,E_AHI_AP_INPUT_RANGE_2,E_AHI_ADC_SRC_ADC_2);
	vAHI_AdcStartSample();//測定開始
	//MyDelay(1000);
	while(bAHI_AdcPoll());//AD変換待ち
	gADC=gADC + u16AHI_AdcRead();//結果読み込み
	//MyDelay(1000);
	vPortSetLo(PORT_OUT1);//OFF設定
	vPortSetLo(PORT_OUT2);//OFF設定
}


/****************************************************************************
 *
 * NAME: vProcessEvent
 *
 * DESCRIPTION:
 *
 * RETURNS:
 *
 ****************************************************************************/
static void vProcessEvCore(tsEvent *pEv, teEvent eEvent, uint32 u32evarg) {
	if (eEvent == E_EVENT_START_UP) {
		// ここで UART のメッセージを出力すれば安全である。
		if (u32evarg & EVARG_START_UP_WAKEUP_RAMHOLD_MASK) {
			vfPrintf(&sSerStream, LB "RAMHOLD");
		}
	    if (u32evarg & EVARG_START_UP_WAKEUP_MASK) {
			vfPrintf(&sSerStream, LB "Wake up by %s. SleepCt=%d",
					bWakeupByButton ? "UART PORT" : "WAKE TIMER",
					sAppData.u8SleepCt);
	    } else {
	    	vfPrintf(&sSerStream, "\r\n*** ToCoNet PINGPONG SAMPLE %d.%02d-%d ***", VERSION_MAIN, VERSION_SUB, VERSION_VAR);
	    	vfPrintf(&sSerStream, "\r\n*** %08x ***", ToCoNet_u32GetSerial());
	    }
	}
}

/****************************************************************************/
/***        END OF FILE                                                   ***/
/****************************************************************************/
